Cosmos DB
=========

.. automodule:: ceds_jsonld.cosmos
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: ceds_jsonld.cosmos.loader
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.cosmos.prepare
   :members:
   :show-inheritance:
